#!/usr/sbin/dtrace -s
/*
 * dnlcps.d - DNLC stats by process.
 *            Written in DTrace (Solaris 10 3/05).
 *
 * The DNLC is the Directory Name Lookup Cache. Filename lookups often
 * return a hit from here, before needing to traverse the regular file
 * system cache or go to disk.
 *
 * dnlcps.d prints DNLC statistics by process.
 *
 * 14-Jun-2005, ver 0.70
 *
 *
 * USAGE:	dnlcps.d        # wait several seconds, then hit Ctrl-C
 *
 * FIELDS:
 *		PID             Process ID
 *		CMD          	Command name
 *		value        	0 == miss, 1 == hit
 *		count        	number of occurrences
 *
 * Standard Disclaimer: This is freeware, use at your own risk.
 *
 * 27-Mar-2004	Brendan Gregg	Created this.
 * 14-Jun-2005	   "      "	Rewrote this a lot.
 */

#pragma D option quiet

/*
 * Print header
 */
dtrace:::BEGIN
{
	printf("Sampling... Hit Ctrl-C to end.\n");
}

/*
 * DNLC return
 */
fbt:genunix:dnlc_lookup:return
{
	this->code = arg1 == 0 ? 0 : 1;
	@Result[execname, pid] = lquantize(this->code, 0, 1, 1);
}

/*
 * Print report
 */
dtrace:::END
{
	printa(" CMD: %-16s PID: %d\n%@d\n",@Result);
}

